@@ -1,5 +1,6 @@
+from django.core.validators import MinValueValidator
 from django.forms import (
-    CharField,
+    CharField, FloatField,
 )
 
 from netbox.forms import (
@@ -15,19 +16,38 @@ from utilities.forms import (
 
 from django.urls import reverse_lazy
 
-from netbox_storage.models import Filesystem, LinuxVolume
+from netbox_storage.models import Filesystem, LinuxVolume, VolumeGroup, Drive, Partition
+from virtualization.models import VirtualMachine
 
 
 class LinuxVolumeForm(NetBoxModelForm):
     """Form for creating a new LinuxVolume object."""
-
-    vg_name = CharField(
-        label="VG Name",
-        help_text="Volume Group Name e.g. docker",
+    virtual_machine = DynamicModelChoiceField(
+        queryset=VirtualMachine.objects.all(),
+        required=False,
     )
-    lv_name = CharField(
-        label="LV Name",
-        help_text="Logical Volume Name e.g. docker",
+    drive = DynamicModelChoiceField(
+        queryset=Drive.objects.all(),
+        query_params={
+            'virtual_machine_id': '$virtual_machine',
+        },
+        help_text="The Storage Cluster of the drive",
+    )
+    partition = DynamicModelChoiceField(
+        queryset=Partition.objects.all(),
+        label="Partition",
+        widget=APISelect(
+            attrs={"data-url": reverse_lazy("plugins-api:netbox_storage-api:partition-list")}
+        ),
+        query_params={
+            'drive_id': '$drive',
+        },
+        help_text="The Partition for the LinuxVolume e.g. /dev/sda1",
+    )
+    size = FloatField(
+        label="Size (GB)",
+        help_text="The size of the logical volume e.g. 25",
+        validators=[MinValueValidator(0.0)],
     )
     path = CharField(
         label="Path",
@@ -46,8 +66,10 @@ class LinuxVolumeForm(NetBoxModelForm):
         model = LinuxVolume
 
         fields = (
-            "vg_name",
-            "lv_name",
+            "virtual_machine",
+            "drive",
+            "partition",
+            "size",
             "fs",
             "path",
             "description",
@@ -59,25 +81,43 @@ class LinuxVolumeFilterForm(NetBoxModelFilterSetForm):
 
     model = LinuxVolume
 
-    vg_name = CharField(
-        required=False,
-        label="VG Name",
+    virtual_machine = DynamicModelChoiceField(
+        queryset=VirtualMachine.objects.all(),
     )
-    lv_name = CharField(
-        required=False,
-        label="LV Name",
+    drive = DynamicModelChoiceField(
+        queryset=Drive.objects.all(),
+        query_params={
+            'virtual_machine_id': '$virtual_machine',
+        },
+        help_text="The Storage Cluster of the drive",
+    )
+    partition = DynamicModelChoiceField(
+        queryset=Partition.objects.all(),
+        label="Partition",
+        widget=APISelect(
+            attrs={"data-url": reverse_lazy("plugins-api:netbox_storage-api:partition-list")}
+        ),
+        query_params={
+            'drive_id': '$drive',
+        },
+        help_text="The Partition for the LinuxVolume e.g. /dev/sda1",
+    )
+    size = FloatField(
+        label="Size (GB)",
+        help_text="The size of the logical volume e.g. 25",
+        validators=[MinValueValidator(0.0)],
     )
     path = CharField(
-        required=False,
         label="Path",
+        help_text="The mounted path of the volume e.g. /var/lib/docker",
     )
     fs = DynamicModelChoiceField(
         queryset=Filesystem.objects.all(),
-        required=False,
+        label="Filesystem Name",
         widget=APISelect(
             attrs={"data-url": reverse_lazy("plugins-api:netbox_storage-api:filesystem-list")}
         ),
-        label="Filesystem Name",
+        help_text="The Filesystem of the Volume e.g. ext4",
     )
 
 
@@ -94,8 +134,6 @@ class LinuxVolumeImportForm(NetBoxModelImportForm):
         model = LinuxVolume
 
         fields = (
-            "vg_name",
-            "lv_name",
             "fs",
             "path",
             "description",
@@ -105,14 +143,6 @@ class LinuxVolumeImportForm(NetBoxModelImportForm):
 class LinuxVolumeBulkEditForm(NetBoxModelBulkEditForm):
     model = LinuxVolume
 
-    vg_name = CharField(
-        required=False,
-        label="VG Name",
-    )
-    lv_name = CharField(
-        required=False,
-        label="LV Name",
-    )
     path = CharField(
         required=False,
         label="Path",
@@ -127,7 +157,7 @@ class LinuxVolumeBulkEditForm(NetBoxModelBulkEditForm):
     fieldsets = (
         (
             None,
-            ("vg_name", "lv_name", "path", "fs", "description"),
+            ("path", "fs", "description"),
         ),
     )
     nullable_fields = ["description"]
