@@ -95,7 +95,7 @@ class Partition(NetBoxModel):
     clone_fields = ["drive", "device", "size", "type", "description"]
 
     prerequisite_models = (
-        'netbox_storage.Partition'
+        'netbox_storage.Drive',
     )
 
     class Meta:
@@ -249,7 +249,7 @@ class LogicalVolume(NetBoxModel):
     fs = models.ForeignKey(
         Filesystem,
         on_delete=models.CASCADE,
-        related_name="fs_linux",
+        related_name="fs_lvm",
         verbose_name="Filesystem",
     )
     description = models.CharField(
@@ -281,3 +281,50 @@ class LogicalVolume(NetBoxModel):
 
     class Meta:
         ordering = ("lv_name", "description")
+
+
+class LinuxVolume(NetBoxModel):
+    partition = models.ForeignKey(
+        Partition,
+        on_delete=models.CASCADE,
+        related_name='partition_linuxvolume',
+    )
+    size = models.FloatField(
+        verbose_name="Size (GB)"
+    )
+    path = models.CharField(
+        max_length=255,
+    )
+    fs = models.ForeignKey(
+        Filesystem,
+        on_delete=models.CASCADE,
+        related_name="fs_linux",
+        verbose_name="Filesystem",
+    )
+    description = models.CharField(
+        max_length=255,
+        blank=True,
+    )
+
+    clone_fields = [
+        "partition",
+        "size",
+        "path",
+        "fs",
+        "description",
+    ]
+
+    prerequisite_models = (
+        'netbox_storage.Filesystem',
+        'netbox_storage.Drive',
+        'netbox_storage.Partition',
+    )
+
+    def get_absolute_url(self):
+        return reverse("plugins:netbox_storage:logicalvolume", kwargs={"pk": self.pk})
+
+    def __str__(self):
+        return f"{self.partition.device}"
+
+    class Meta:
+        ordering = ("size", "path", "description")
