@@ -9,62 +9,37 @@ from netbox.tables import (
 from netbox_storage.models import LinuxVolume
 
 
-class LinuxVolumeBaseTable(NetBoxTable):
-    """Base class for tables displaying LinuxVolume"""
+class LinuxVolumeTable(NetBoxTable):
+    """Table for displaying LinuxVolume objects."""
 
+    pk = ToggleColumn()
     fs = tables.Column(
         linkify=True,
         verbose_name="Filesystem"
     )
-    vg_name = tables.Column(
+    partition = tables.Column(
         linkify=True,
-        verbose_name="Volume Group Name"
+        verbose_name="Partition"
     )
-    lv_name = tables.Column(
+    size = tables.Column(
         linkify=True,
-        verbose_name="Logical Volume Name"
+        verbose_name="Size"
     )
 
-
-class LinuxVolumeTable(LinuxVolumeBaseTable):
-    """Table for displaying LinuxVolume objects."""
-
-    pk = ToggleColumn()
-
     class Meta(NetBoxTable.Meta):
         model = LinuxVolume
         fields = (
             "pk",
-            "vg_name",
-            "lv_name",
+            "partition",
+            "size",
             "path",
             "fs",
             "description",
         )
         default_columns = (
-            "vg_name",
-            "lv_name",
-            "path",
-            "fs",
-            "description"
-        )
-
-
-class RelatedLinuxVolumeTable(LinuxVolumeBaseTable):
-    actions = ActionsColumn(actions=())
-
-    class Meta(NetBoxTable.Meta):
-        model = LinuxVolume
-        fields = (
-            "pk",
-            "vg_name",
-            "lv_name",
+            "partition",
+            "size",
             "path",
             "fs",
             "description",
         )
-        default_columns = (
-            "fs",
-            "description"
-        )
-
